==> freecad_0.18.4+dfsg2.orig.tar.xz: FreeCAD-0.18.4/src/Mod/Test/Gui/Resources/translations/Test_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lt" sourcelanguage="en">
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <location filename="../../UnitTest.ui" line="16"/>
      <source>FreeCAD UnitTest</source>
      <translation>FreeCAD modulių patikra</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="31"/>
      <source>Failures and errors</source>
      <translation>Triktys ir klaidos</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="47"/>
      <source>Description</source>
      <translation>Aprašymas</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="82"/>
      <source>&amp;Start</source>
      <translation>&amp;Pradžia</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="85"/>
      <source>Alt+S</source>
      <translation>Alt+S</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="114"/>
      <source>&amp;Help</source>
      <translation>Ž&amp;inynas</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="117"/>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="127"/>
      <source>&amp;About</source>
      <translation>&amp;Apie</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="130"/>
      <source>Alt+A</source>
      <translation>Alt+A</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="140"/>
      <source>&amp;Close</source>
      <translation>&amp;Užverti</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="143"/>
      <source>Alt+C</source>
      <translation>Alt+C</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="161"/>
      <source>Idle</source>
      <translation>Neveiklus</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="168"/>
      <source>Progress</source>
      <translation>Atlikta</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="197"/>
      <source>Remaining:</source>
      <translation>Liko:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="214"/>
      <source>Errors:</source>
      <translation>Klaidos:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="231"/>
      <source>Failures:</source>
      <translation>Triktys:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="248"/>
      <source>Run:</source>
      <translation>Atlikti:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="258"/>
      <source>Test</source>
      <translation>Patikrinti</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="270"/>
      <source>Select test name:</source>
      <translation>Parinkite patikros vardą:</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <location filename="../../UnitTestImp.cpp" line="162"/>
      <source>Help</source>
      <translation>Žinynas</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="162"/>
      <source>Enter the name of a callable object which, when called, will return a TestCase.
Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it, including the stack trace.</source>
      <translation type="unfinished">Enter the name of a callable object which, when called, will return a TestCase.
Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it, including the stack trace.</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="174"/>
      <source>About FreeCAD UnitTest</source>
      <translation>Apie FreeCAD modulių patikrą</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="174"/>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for ones own modules.</source>
      <translation type="unfinished">Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for ones own modules.</translation>
    </message>
  </context>
</TS>

==> freecad_0.19.2+dfsg1.orig.tar.xz: FreeCAD-0.19.2/src/Mod/Test/Gui/Resources/translations/Test_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt" sourcelanguage="en">
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <location filename="../../UnitTest.ui" line="16"/>
      <source>FreeCAD UnitTest</source>
      <translation>FreeCAD modulių patikra</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="31"/>
      <source>Failures and errors</source>
      <translation>Triktys ir klaidos</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="47"/>
      <source>Description</source>
      <translation>Aprašymas</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="82"/>
      <source>&amp;Start</source>
      <translation>&amp;Pradžia</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="85"/>
      <source>Alt+S</source>
      <translation>Alt+S</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="114"/>
      <source>&amp;Help</source>
      <translation>Ž&amp;inynas</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="117"/>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="127"/>
      <source>&amp;About</source>
      <translation>&amp;Apie</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="130"/>
      <source>Alt+A</source>
      <translation>Alt+A</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="140"/>
      <source>&amp;Close</source>
      <translation>&amp;Užverti</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="143"/>
      <source>Alt+C</source>
      <translation>Alt+C</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="161"/>
      <source>Idle</source>
      <translation>Neveiklus</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="168"/>
      <source>Progress</source>
      <translation>Atliekama</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="197"/>
      <source>Remaining:</source>
      <translation>Liko:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="214"/>
      <source>Errors:</source>
      <translation>Klaidos:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="231"/>
      <source>Failures:</source>
      <translation>Gedimai:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="248"/>
      <source>Run:</source>
      <translation>Atlikti:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="258"/>
      <source>Test</source>
      <translation>Tikrinti</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="270"/>
      <source>Select test name:</source>
      <translation>Parinkite patikros vardą:</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <location filename="../../UnitTestImp.cpp" line="164"/>
      <source>Help</source>
      <translation>Žinynas</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="164"/>
      <source>Enter the name of a callable object which, when called, will return a TestCase.
Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it, including the stack trace.</source>
      <translation>Įveskite iškviečiamo objekto pavadinimą, kurį iškvietus bus grąžinamas bandymo atvejis. Paspaudus „Pradėti“, taip sudarytas bandymas bus įvykdytas.

Dukart spustelėkite klaidą medžio rodinyje ir gausite išsamų aprašą apie apie ja, įskaitant dėklo pėdsaką.</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="176"/>
      <source>About FreeCAD UnitTest</source>
      <translation>Apie FreeCAD modulių patikrą</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="176"/>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for ones own modules.</source>
      <translation>Autorinės teisės (c) Werner Mayer

„FreeCAD“ modulių patikra yra programos „FreeCAD“ dalis, palaikanti savų modulių patikrą.</translation>
    </message>
  </context>
</TS>
